@@ -1,29 +1,18 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005-2006 Olivier Goffart <ogoffart at kde.org>
-   Copyright (C) 2013-2014 Martin Klapetek <mklapetek@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005-2006 Olivier Goffart <ogoffart at kde.org>
+    SPDX-FileCopyrightText: 2013-2014 Martin Klapetek <mklapetek@kde.org>
 
-   code from KNotify/KNotifyClient
-   Copyright (c) 1997 Christian Esken (esken@kde.org)
-                 2000 Charles Samuels (charles@kde.org)
-                 2000 Stefan Schimanski (1Stein@gmx.de)
-                 2000 Matthias Ettrich (ettrich@kde.org)
-                 2000 Waldo Bastian <bastian@kde.org>
-                 2000-2003 Carsten Pfeiffer <pfeiffer@kde.org>
-                 2005 Allan Sandfeld Jensen <kde@carewolf.com>
+    code from KNotify/KNotifyClient
+    SPDX-FileCopyrightText: 1997 Christian Esken <esken@kde.org>
+    SPDX-FileCopyrightText: 2000 Charles Samuels <charles@kde.org>
+    SPDX-FileCopyrightText: 2000 Stefan Schimanski <1Stein@gmx.de>
+    SPDX-FileCopyrightText: 2000 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000-2003 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2005 Allan Sandfeld Jensen <kde@carewolf.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "knotification.h"
@@ -31,7 +20,6 @@
 
 #include <QCoreApplication>
 
-#include <QPixmap>
 #include <QTimer>
 #include <QTabWidget>
 #include <QStringList>
@@ -39,10 +27,10 @@
 
 struct Q_DECL_HIDDEN KNotification::Private {
     QString eventId;
-    int id;
-    int ref;
+    int id = -1;
+    int ref = 0;
 
-    QWidget *widget;
+    QWidget *widget = nullptr;
     QString title;
     QString text;
     QString iconName;
@@ -52,14 +40,12 @@ struct Q_DECL_HIDDEN KNotification::Private {
     ContextList contexts;
     NotificationFlags flags;
     QString componentName;
-    QList<QUrl> urls;
-    KNotification::Urgency urgency;
+    KNotification::Urgency urgency = KNotification::DefaultUrgency;
     QVariantMap hints;
 
     QTimer updateTimer;
-    bool needUpdate;
+    bool needUpdate = false;
 
-    Private() : id(-1), ref(0), widget(nullptr), urgency(KNotification::DefaultUrgency), needUpdate(false) {}
 #if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 67)
     /**
      * recursive function that raise the widget. @p w
@@ -70,6 +56,7 @@ struct Q_DECL_HIDDEN KNotification::Private {
 #endif
 };
 
+#if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 75)
 KNotification::KNotification(const QString &eventId, QWidget *parent, const NotificationFlags &flags) :
     QObject(parent), d(new Private)
 {
@@ -80,6 +67,7 @@ KNotification::KNotification(const QString &eventId, QWidget *parent, const Noti
     d->updateTimer.setSingleShot(true);
     d->updateTimer.setInterval(100);
 }
+#endif
 
 KNotification::KNotification(
     const QString &eventId,
@@ -272,20 +260,12 @@ void KNotification::setComponentName(const QString &c)
 
 QList<QUrl> KNotification::urls() const
 {
-    return d->urls;
+    return QUrl::fromStringList(d->hints[QStringLiteral("x-kde-urls")].toStringList());
 }
 
 void KNotification::setUrls(const QList<QUrl> &urls)
 {
-    if (d->urls == urls) {
-        return;
-    }
-
-    d->needUpdate = true;
-    d->urls = urls;
-    if (d->id >= 0) {
-        d->updateTimer.start();
-    }
+    setHint(QStringLiteral("x-kde-urls"), QUrl::toStringList(urls));
 }
 
 KNotification::Urgency KNotification::urgency() const
@@ -310,7 +290,9 @@ void KNotification::activate(unsigned int action)
 {
     switch (action) {
     case 0:
+#if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 76)
         emit activated();
+#endif
         emit defaultActivated();
         break;
     case 1:
@@ -384,7 +366,8 @@ static QString defaultComponentName()
 KNotification *KNotification::event(const QString &eventid, const QString &title, const QString &text,
                                     const QPixmap &pixmap, QWidget *widget, const NotificationFlags &flags, const QString &componentName)
 {
-    KNotification *notify = new KNotification(eventid, widget, flags);
+    KNotification *notify = new KNotification(eventid, flags);
+    notify->setWidget(widget);
     notify->setTitle(title);
     notify->setText(text);
     notify->setPixmap(pixmap);
@@ -418,7 +401,8 @@ KNotification *KNotification::event(const QString &eventid, const QString &title
                                 const QString &iconName, QWidget *widget,
                                 const NotificationFlags &flags, const QString &componentName)
 {
-    KNotification *notify = new KNotification(eventid, widget, flags);
+    KNotification *notify = new KNotification(eventid, flags);
+    notify->setWidget(widget);
     notify->setTitle(title);
     notify->setText(text);
     notify->setIconName(iconName);
