@@ -1,21 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright 2009 by Marco Martin <notmart@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2009 Marco Martin <notmart@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License (LGPL) as published by the Free Software Foundation;
-   either version 2 of the License, or (at your option) any later
-   version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kstatusnotifieritem.h"
@@ -31,9 +18,9 @@
 #include <QMenu>
 #include <QMovie>
 #include <QPainter>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #ifdef Q_OS_MACOS
-#include <qfontdatabase.h>
+#include <QFontDatabase>
 #include <QtMac>
 #endif
 
@@ -48,7 +35,7 @@
 #endif
 
 #include <QTimer>
-#include <kwindowinfo.h>
+#include <KWindowInfo>
 #include <kwindowsystem.h>
 
 #include <cstdlib>
@@ -448,11 +435,10 @@ void KStatusNotifierItem::setToolTipSubTitle(const QString &subTitle)
     }
 
     d->toolTipSubTitle = subTitle;
-#ifdef Q_OS_MACOS
-    setTrayToolTip(d->systemTrayIcon, d->toolTipTitle, subTitle);
-#endif
 #ifdef QT_DBUS_LIB
     emit d->statusNotifierItemDBus->NewToolTip();
+#else
+    setTrayToolTip(d->systemTrayIcon, d->toolTipTitle, subTitle);
 #endif
 }
 
@@ -542,7 +528,7 @@ void KStatusNotifierItem::setAssociatedWidget(QWidget *associatedWidget)
         if (!action) {
             action = new QAction(this);
             d->actionCollection.insert(QStringLiteral("minimizeRestore"), action);
-            action->setText(tr("&Minimize"));
+            action->setText(tr("&Minimize", "@action:inmenu"));
             connect(action, SIGNAL(triggered(bool)), this, SLOT(minimizeRestore()));
         }
 
@@ -615,35 +601,32 @@ bool KStatusNotifierItem::standardActionsEnabled() const
 
 void KStatusNotifierItem::showMessage(const QString &title, const QString &message, const QString &icon, int timeout)
 {
-#ifdef Q_OS_MACOS
+#ifdef QT_DBUS_LIB
+    if (!d->notificationsClient) {
+        d->notificationsClient = new org::freedesktop::Notifications(QStringLiteral("org.freedesktop.Notifications"), QStringLiteral("/org/freedesktop/Notifications"),
+                                                                     QDBusConnection::sessionBus());
+    }
+
+    uint id = 0;
+    QVariantMap hints;
+
+    QString desktopFileName = QGuiApplication::desktopFileName();
+    if (!desktopFileName.isEmpty()) {
+        // handle apps which set the desktopFileName property with filename suffix,
+        // due to unclear API dox (https://bugreports.qt.io/browse/QTBUG-75521)
+        if (desktopFileName.endsWith(QLatin1String(".desktop"))) {
+            desktopFileName.chop(8);
+        }
+        hints.insert(QStringLiteral("desktop-entry"), desktopFileName);
+    }
+
+    d->notificationsClient->Notify(d->title, id, icon, title, message, QStringList(), hints, timeout);
+#else
     if (d->systemTrayIcon) {
         // Growl is not needed anymore for QSystemTrayIcon::showMessage() since OS X 10.8
         d->systemTrayIcon->showMessage(title, message, QSystemTrayIcon::Information, timeout);
-    } else
-#endif
-    {
-#ifdef QT_DBUS_LIB
-        if (!d->notificationsClient) {
-            d->notificationsClient = new org::freedesktop::Notifications(QStringLiteral("org.freedesktop.Notifications"), QStringLiteral("/org/freedesktop/Notifications"),
-                                                                         QDBusConnection::sessionBus());
-        }
-
-        uint id = 0;
-        QVariantMap hints;
-
-        QString desktopFileName = QGuiApplication::desktopFileName();
-        if (!desktopFileName.isEmpty()) {
-            // handle apps which set the desktopFileName property with filename suffix,
-            // due to unclear API dox (https://bugreports.qt.io/browse/QTBUG-75521)
-            if (desktopFileName.endsWith(QLatin1String(".desktop"))) {
-                desktopFileName.chop(8);
-            }
-            hints.insert(QStringLiteral("desktop-entry"), desktopFileName);
-        }
-
-        d->notificationsClient->Notify(d->title, id, icon, title, message, QStringList(), hints, timeout);
-#endif
     }
+#endif
 }
 
 QString KStatusNotifierItem::title() const
@@ -807,10 +790,10 @@ KStatusNotifierItemPrivate::KStatusNotifierItemPrivate(KStatusNotifierItem *item
       category(KStatusNotifierItem::ApplicationStatus),
       status(KStatusNotifierItem::Passive),
       movie(nullptr),
+      systemTrayIcon(nullptr),
       menu(nullptr),
       associatedWidget(nullptr),
       titleAction(nullptr),
-      systemTrayIcon(nullptr),
       hasQuit(false),
       onAllDesktops(false),
       standardActionsEnabled(true)
@@ -863,7 +846,7 @@ void KStatusNotifierItemPrivate::init(const QString &extraId)
     q->setContextMenu(m);
 
     QAction *action = new QAction(q);
-    action->setText(KStatusNotifierItem::tr("Quit"));
+    action->setText(KStatusNotifierItem::tr("Quit", "@action:inmenu"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("application-exit")));
     // cannot yet convert to function-pointer-based connect:
     // some apps like kalarm or korgac have a hack to rewire the connection
@@ -878,7 +861,7 @@ void KStatusNotifierItemPrivate::init(const QString &extraId)
     }
 
     // Init iconThemePath to the app folder for now
-    iconThemePath = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
+    iconThemePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
 
     registerToDaemon();
 }
@@ -926,6 +909,8 @@ void KStatusNotifierItemPrivate::registerToDaemon()
         qCDebug(LOG_KNOTIFICATIONS) << "KStatusNotifierWatcher not reachable";
         useLegacy = true;
     }
+#else
+    useLegacy = true;
 #endif
     setLegacySystemTrayEnabled(useLegacy);
 }
@@ -1120,9 +1105,9 @@ void KStatusNotifierItemPrivate::contextMenuAboutToShow()
     if (associatedWidget && associatedWidget != menu) {
         QAction *action = actionCollection.value(QStringLiteral("minimizeRestore"));
         if (checkVisibility(QPoint(0, 0), false)) {
-            action->setText(KStatusNotifierItem::tr("&Restore"));
+            action->setText(KStatusNotifierItem::tr("&Restore", "@action:inmenu"));
         } else {
-            action->setText(KStatusNotifierItem::tr("&Minimize"));
+            action->setText(KStatusNotifierItem::tr("&Minimize", "@action:inmenu"));
         }
     }
 }
@@ -1137,7 +1122,7 @@ void KStatusNotifierItemPrivate::maybeQuit()
     QString query = KStatusNotifierItem::tr("<qt>Are you sure you want to quit <b>%1</b>?</qt>").arg(caption);
 
     if (QMessageBox::question(associatedWidget,
-                              KStatusNotifierItem::tr("Confirm Quit From System Tray"), query) == QMessageBox::Yes) {
+                              KStatusNotifierItem::tr("Confirm Quit From System Tray", "@title:window"), query) == QMessageBox::Yes) {
         qApp->quit();
     }
 
